@@ -1,24 +1,31 @@
 import os
 import traceback
 
-from .logging import elogger
+from zuper_commons.types import ZException
+
+from . import logger
+
+
+class IPFSException(ZException):
+    pass
 
 
 def ipfs_available():
     if os.path.exists("/ipfs"):
         fn = "/ipfs/QmYwAPJzv5CZsnA625s3Xf2nemtYgPpHdWEz79ojWnPbdG/readme"
+        # noinspection PyBroadException
         try:
             d = open(fn).read()
         except:
             msg = f"Could not open an IPFS file: {traceback.format_exc()}"
-            elogger.warning(msg)
+            logger.warning(msg)
             return False
 
         if "Hello" in d:
             return True
         else:
-            elogger.warning(d)
+            logger.warning(d)
             return False
     else:
-        elogger.warning("/ipfs not found")
+        logger.warning("/ipfs not found")
         return False
