@@ -1020,6 +1020,7 @@ def run_single(
         for service_name, s in config["services"].items():
             image = s["image"]
             if "dummy" in image:
+                logger.info(f'skipping image {image}')
                 continue
             docker_pull_retry(client, image, ntimes=4, wait=5, credentials=credentials, quiet=False)
     if valid_config:
@@ -1437,10 +1438,13 @@ def get_config(
 
     for service_name, service in config["services"].items():
         image = service["image"]
+
         br = parse_complete_tag(image)
-        br.tag = None
+        if image != solution_container:
+            br.tag = None
         service["image"] = get_complete_tag(br)
 
+        logger.info(f'translating {image} -> {service["image"]}')
         if quiet:
             if not is_solution_container(service_name):
                 service["logging"] = {"driver": "none"}
