@@ -1,5 +1,6 @@
 # coding=utf-8
 import argparse
+import getpass
 import logging
 import os
 import random
@@ -216,10 +217,11 @@ For example, you could try:
     steps_ordered = list(sorted(cd.steps))
     logger.debug("steps", steps_ordered=steps_ordered)
     output = parsed.output
+    user = getpass.getuser()
     if output is None:
         timestamp = datetime.now().strftime("%y_%m_%d_%H_%M_%S")
 
-        output = os.path.join("/tmp/duckietown/dt-challenges-runner/local-evals", one, timestamp)
+        output = os.path.join(f"/tmp/{user}/duckietown/dt-challenges-runner/local-evals", one, timestamp)
     logger.info(f"Using output directory {output}")
     for i, challenge_step_name in enumerate(steps_ordered):
         logger.debug(f'Now considering step "{challenge_step_name}"')
